<?php
/*
Theme Name: BIZ-Concept
Theme URI:
Description: 
Author: Helen RIPLEY - Biz-Concept.net
Author URI: https://biz-concept.net
Template: 
Version: 0.1.0 (Initial revision)
Text Domain: twentyseventeen-child
License: GNU General Public License v2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
Tags: WP fr_FR dummy forced french feminisation removal
*/

	// Repousse les tentatives d'accès direct
	if ( !defined( 'ABSPATH' ) ) exit;

	// Pilotage des options
	const BC_fr_FR_FILTER = true; 	// Défaut Filtre Actif : true
	
	// Outils de traitement des traductions inclusives
	require(CT_INSTALL_DIRECTORY.'/includes/translations/ct-translations-tools.php');

	// Classe d'extension pour la gestion des fichiers de traductions de type PO/MO
	include_once CT_INSTALL_DIRECTORY.'/classes/class-ct-translations.php'; 

	/**
	 ** Test de la version courante de WordPress
	 ** Vers.: 0.1.0 (Initiale)
	 ** Usage: Traductions
	 ** @return bool true Si la version courante de Wordpress >= 5.6.0 , sinon false.
	 **/
	function CT_check_current_wordpress(){
		require ABSPATH . WPINC . '/version.php'; // $wp_version; // x.y.z
		return(version_compare('5.6.0',$wp_version ,'<'));
	}

	/**
	 ** Recherche des domaines linguistiques chargés
	 ** Vers.: 0.1.0 (Initiale)
	 ** Usage: Traductions
	 ** @return array             $aDomains     Tableau contenant les clef trouvées.
	 **/
	function CT_get_loaded_domains(){	
		global $l10n;
		$aDomains = array_keys($l10n);
		return ($aDomains);
	}

	/**
	 ** Evolution de la fonction load_textdomain
	 ** Vers.: 0.1.0 (Initiale)
	 ** Usage: Traductions
	 ** @param  string            $domain       Domaine du texte.
	 ** @param  string            $mofile 		Fichier mo.
	 ** @return bool true Si le chargement à réussi, sinon false.
	 **/
	function CT_load_textdomain( $domain, $mofile ) {
		global $l10n, $l10n_unloaded;
		
		$l10n_unloaded = (array) $l10n_unloaded;
		
		/**
		* Filters whether to override the .mo file loading.
		*/
		$plugin_override = apply_filters( 'override_load_textdomain', false, $domain, $mofile );
		
		if ( true === (bool) $plugin_override ) {
			unset( $l10n_unloaded[ $domain ] );
		
			return true;
		}
		
		/**
		* Fires before the MO translation file is loaded.
		*/
		do_action( 'load_textdomain', $domain, $mofile );
		
		/**
		* Filters MO file path for loading translations for a specific text domain.
		*/
		$mofile = apply_filters( 'load_textdomain_mofile', $mofile, $domain );
		
		if ( ! is_readable( $mofile ) ) {
			return false;
		}
		
		//Mise en oeuvre de la surcharge de la classe MO pour la mise en forme des traductions WP fr_FR (Mode non genré dit "inclusif") en fr_FR correct
		$ct_mo = new CT_MO();
			if ( ! $ct_mo->CT_import_from_file( $mofile ) ) {
			return false;
		}
		
		if ( isset( $l10n[ $domain ] ) ) {
			$ct_mo->merge_with( $l10n[ $domain ] );
		}
		
		unset( $l10n_unloaded[ $domain ] );
		
		$l10n[ $domain ] = &$ct_mo;
		
		return true;
	}

	/**
	 ** Activation du domaine du thème enfant (Translation-Ready)
 	 ** Vers.: 0.1.0
	 ** Usage: Traductions
	 **/
	function CT_language_setup() {
		if(defined('BC_PARENT_THEME')){
			load_child_theme_textdomain( BC_PARENT_THEME.'-child', ABSPATH.'wp-content/themes/'.BC_PARENT_THEME.'-child/languages' );
		}
	}
	add_action( 'after_setup_theme', 'CT_language_setup' );

	/**
	 ** Filtre des traductions fr_FR (Mode non genré dit "inclusif") (WP, Thème et Extensions)
	 ** Vers.: 0.1.0 (Initiale)
	 ** Usage: Traductions
	 ** @return bool true Si le chargement à réussi, sinon false.
	 **/
	function CT_reload_default_textdomain(){
		$return = true;
		
		//Applicable à partir de la version WP 5.6.0
		if (CT_check_current_wordpress()== false) {
			return true;
		}
		
		//Traductions fr_FR (Mode non genré dit "inclusif") par défaut
		if (BC_fr_FR_FILTER == false) {
			return true;
		}
		
		//Filtrage des traductions WP fr_FR (Mode non genré dit "inclusif")
		$locale = determine_locale();
		if ($locale != "fr_FR") {
			return true;
		}
		
		//Récupération de la liste des domaines chargés
		$aDomains = CT_get_loaded_domains();
		
		//Récupération des informations propres au theme
		$oThemeInfos = wp_get_theme();
		$oParentThemeInfos = $oThemeInfos->parent();
		$aTheme = array();
		// Theme Enfant dérivé d'un theme parent
		if (!empty($oParentThemeInfos)) {
			$aTheme['child'] = true;
			$aTheme['TextDomain'] = $oParentThemeInfos->get( 'TextDomain' );
			$aTheme['path'] = WP_LANG_DIR . '/themes/';
			$aTheme['file'] = $aTheme['TextDomain']. '-' . $locale;
			$aTheme['inclusive'] = CT_check_inclusive_POfile($aTheme['path'].$aTheme['file'].'.po');
		}
		else {
			$aTheme['child'] = false;
			$aTheme['TextDomain']= $oThemeInfos->get( 'TextDomain' );
			$aTheme['path'] = WP_LANG_DIR . '/themes/';
			$aTheme['file'] = $aTheme['TextDomain']. '-' . $locale;
			$aTheme['inclusive'] = CT_check_inclusive_POfile($aTheme['path'].$aTheme['file'].'.po');
		}
		
		// Déchargement des chaines précédemment chargées dans un theme inclusif afin d'en modifier les traductions
		if (in_array($aTheme['TextDomain'],$aDomains ) && ($aTheme['inclusive']==true)) {
			unload_textdomain( $aTheme['TextDomain'] );
			CT_load_textdomain( $aTheme['TextDomain'], $aTheme['path'].$aTheme['file'].'.mo' );
		}
		
		//Récupération des informations propres aux extensions
		$aPluginsInfos = get_plugins();
		$aPlugins = array();
		if (!empty($aPluginsInfos)) {
			$jKey = 0;
			foreach($aPluginsInfos as $iKey=> $aPluginInfos)
			{
				// Extensions actives
				if(is_plugin_active($iKey))
				{
					$aPlugins[$jKey]['TextDomain'] = $aPluginInfos['TextDomain'];
					
					//Répertoire wp-content/languages/plugins/plugin_text_domain_locale.po
					$sPath = WP_LANG_DIR . '/plugins/';
					$sFile = $aPluginInfos['TextDomain'] . '-' . $locale ;
					$sCheckFile = $sPath.$sFile.'.po';
					if (file_exists($sCheckFile)==true) 
					{
						$aPlugins[$jKey]['path'] = $sPath;
						$aPlugins[$jKey]['file'] = $sFile;
						$aPlugins[$jKey]['inclusive'] = CT_check_inclusive_POfile($sCheckFile);
					}
					else {
						//Répertoire wp-content/languages/plugins/plugin_text_domain/language/plugin_text_domain_locale.mo
						$sPath = WP_CONTENT_DIR . '/plugins/' .$aPluginInfos['TextDomain']. '/languages/';
						$sCheckFile = $sPath.$sFile.'.po';
						if (file_exists($sCheckFile)==true) {
							$aPlugins[$jKey]['path'] = $sPath;
							$aPlugins[$jKey]['file'] = $sFile;
							$aPlugins[$jKey]['inclusive'] = CT_check_inclusive_POfile($sCheckFile);
						}
						//Non identifié
						else {
							$aPlugins[$jKey]['path'] = '';
							$aPlugins[$jKey]['file'] = '';
							$aPlugins[$jKey]['inclusive'] = false;
						}
					}
					$jKey ++;
				}
			}
		}
		
		//Extensions actives
		if(!empty($aPlugins))
		{
			foreach($aPlugins as $aPlugin)
			{
				//Extension inclusive
				if ((!(empty($aPlugin['file']))) && ($aPlugin['inclusive']==true)) {
					// Déchargement des chaines précédemment chargées dans une extension inclusive afin de modifier les traductions
					unload_textdomain( $aPlugin['TextDomain'] );
					CT_load_textdomain( $aPlugin['TextDomain'], $aPlugin['path'].$aPlugin['file'].'.mo' );
				}
			}
		}
		
		// Déchargement des chaines WP inclusives par défaut précédemment chargées afin de modifier les traductions
		unload_textdomain( 'default' );
		$return = CT_load_textdomain( 'default', WP_LANG_DIR . "/$locale.mo" );
		
		if ( ( is_multisite() || ( defined( 'WP_INSTALLING_NETWORK' ) && WP_INSTALLING_NETWORK ) ) && ! file_exists( WP_LANG_DIR . "/admin-$locale.mo" ) ) {
			CT_load_textdomain( 'default', WP_LANG_DIR . "/ms-$locale.mo" );
			return $return;
		}
		
		if ( is_admin() || wp_installing() || ( defined( 'WP_REPAIRING' ) && WP_REPAIRING ) ) {
			CT_load_textdomain( 'default', WP_LANG_DIR . "/admin-$locale.mo" );
		}
		
		if ( is_network_admin() || ( defined( 'WP_INSTALLING_NETWORK' ) && WP_INSTALLING_NETWORK ) ) {
			CT_load_textdomain( 'default', WP_LANG_DIR . "/admin-network-$locale.mo" );
		}
		return $return;
	}
	//Priorite faible (20) pour s'assurer que toutes les traductions sauf celles du theme enfant aient bien été chargées avant le traitement final
	add_action( 'after_setup_theme', 'CT_reload_default_textdomain', 20 );

	/**
	 ** Filtre de traduction WP fr_FR (Mode non genré dit "inclusif") messages des scripts (js/json)
	 ** Vers.: 0.1.0 (Initiale)
	 ** Usage: Traductions
	 ** @param  string|false|null $translations Traductions au format JSON. Défaut null.
	 ** @param  string|false      $file         Chemin du fichier de traduction à charger. false S'il n'y en a pas.
	 ** @param  string            $handle       Nom du script pour lequel doit être enregistré un domaine de traduction.
	 ** @param  string            $domain       Domaine du texte.
	 ** @return string Traductions au format JSON.
	 **/
	function CT_blocks_get_i18n_data_json( $translations, $file, $handle, $domain ) {
		
		//Applicable à partir de la version WP 5.6.0
		if (CT_check_current_wordpress()== false){
			return $translations;
		}
		
		//Traductions fr_FR (Mode non genré dit "inclusif") par défaut
		if (BC_fr_FR_FILTER == false)
			return $translations;
		
		global $wp_scripts;
		
		//Script non enregistré
		if ( ! isset( $wp_scripts->registered[ $handle ], $wp_scripts->registered[ $handle ]->src ) ) {
			return $translations;
		}
		
		//Chargement des données du fichier
		$rawData = is_file( $file ) && is_readable( $file) ? file_get_contents( $file ) : false;
		
		//Présence de données dans le fichier
		if ($rawData) {
			
			$aRawData = json_decode($rawData);
			
			//Traitement des données JSON extraites du fichier
			if ($aRawData) {
				//Traitement de tous les messages
				$aNewData = array();
				foreach ($aRawData->locale_data->messages as $mKey => $values)
				{
					//Traitement de tous les messages d'origine (en anglais)
					if (!empty($mKey))
					{
						//Traitement des tous les messages WP fr_FR (Mode non genré dit "inclusif")
						$aCleared = array();
						if ($values)
						{
							foreach ($values as $vKey => $value)
							{
								//Mise en forme des messages WP fr_FR (Mode non genré dit "inclusif") en fr_FR correct
								$aCleared[$vKey] = CT_WP_remove_dummy_forced_french_feminisation( $value, $mKey, "DEBUG");
							}
						}
						//Intégration des messages modifiés
						$aNewData[$mKey]=$aCleared;
					}
					//Autres données
					else
					{
						if (!empty($values)){
							$aNewData[$mKey]= (object)$values;
						}
					}
				}
				//Mise en forme du résultat du traitement
				$aRawData->locale_data->messages = (object) $aNewData;
				
				//Encodage du résultat en JSON
				$translations = json_encode($aRawData);
				
				//Applicable avant la version PHP 7.1.0
				if(version_compare(phpversion(),'7.1.0','<')){
					$translations = CT_search_replace_text('"_empty_"','""',$translations);
				}
			}
		}
		
		//Retour du resultat sous forme d'une structure JSON
		if ($translations) return($translations);
		
		//Retour d'une structure JSON locale valide et vide
		return '{ "locale_data": { "messages": { "": {} } } }';
	}
	add_filter( 'pre_load_script_translations', 'CT_blocks_get_i18n_data_json', 10, 4 );

